pub struct ChunkCharIndex<'text> {
pub chunk: &'text str,
pub byte_offset: usize,
pub char_offset: usize,
}Expand description
Represents a chunk of text along with its byte and character offsets.
Fields
chunk: &'text strThe text of the generated chunk.
byte_offset: usizeThe byte offset of the chunk within the original text.
char_offset: usizeThe character offset of the chunk within the original text.